OC.L10N.register(
    "circles",
    {
    "Personal" : "Udmawan",
    "Open" : "Ldi",
    "Local" : "Adigan",
    "Email address" : "Tansa imayl",
    "Circle" : "Tawinest",
    "Moderator" : "Amaẓrag",
    "Admin" : "Anedbal",
    "Owner" : "Bab",
    "No entries found in this folder" : "Ulac inekcumen i yettwafen deg ukaram-a",
    "Name" : "Nom",
    "Size" : "Teɣzi",
    "Modified" : "Yettwabeddel"
},
"nplurals=2; plural=(n != 1);");
